.. vk_maria documentation master file, created by
   sphinx-quickstart on Mon Apr  4 14:48:43 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to vk_maria's documentation!
====================================

   .. image:: https://img.shields.io/badge/telegram-vk_maria-blue.svg?style=flat-square
      :target: https://t.me/vk_maria_ru
      :alt: [Telegram] vk_maria live

   .. image:: https://img.shields.io/pypi/v/vk_maria.svg?style=flat-square
      :target: https://pypi.python.org/pypi/vk_maria
      :alt: PyPi Package Version

   .. image:: https://img.shields.io/pypi/dm/vk_maria.svg?style=flat-square
      :target: https://pypi.python.org/pypi/vk_maria
      :alt: PyPi Month Downloads

   .. image:: https://pepy.tech/badge/vk-maria
      :target: https://pepy.tech/project/vk-maria
      :alt: PyPi Total Downloads

   .. image:: https://img.shields.io/pypi/pyversions/vk_maria.svg?style=flat-square
      :target: https://pypi.python.org/pypi/vk_maria
      :alt: Supported python versions

**vk_maria** очень простой фреймворк для создания ботов сообществ `Vk <https://dev.vk.com/reference>`_, написанный на Python 3.8.

Официальные ресурсы vk_maria
----------------------------
- Новости: `@vk_maria <https://t.me/vk_maria_ru>`_
- Чат комьюнити: `@vk_maria_ru <https://t.me/vk_maria_ru_chat>`_
- Pip: `vk_maria <https://pypi.org/project/vk-maria/>`_
- Docs: `ReadTheDocs <https://vk-maria.readthedocs.io/ru/latest/>`_
- Source: `Github репозиторий <https://github.com/lxstvayne/vk_maria>`_
- Issues/Bug tracker: `Github issues tracker <https://github.com/lxstvayne/vk_maria/issues>`_

Сильные стороны
----------------
- Простота и удобство
- Наличие конечных автоматов (FSM)
- Типизированная
